<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ReportImpactAnalysis.xsl"/>
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- The code here is pulled from early implementations of the report. 					-->
	<!-- This WILL produce a report, but it will not be as robust and polished as Archive. -->
	<xsl:template match="optimreport:DeleteReport">
		<xsl:param name="display">True</xsl:param>
		
		<!-- SET UP CLOSE/EXPAND BY DEFAULT-->
		<xsl:variable name="displayStyle">
			<xsl:choose>
				<xsl:when test="$display='True'">
					<xsl:text></xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>display:none</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<!--BEGIN SUMMARY SECTION-->
		<xsl:apply-templates select="optimreport:summary[@*]">
			<xsl:with-param name="display" select="$display"/>
		</xsl:apply-templates>
		<!--END SUMMARY SECTION-->

		<!--Set up anchor-->
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>
		
		<!-- Process Details Title Bar -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">
				<xsl:choose>
					<xsl:when test="$display='True'">
						<xsl:text>false</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>true</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="isInnerReport">false</xsl:with-param>
		</xsl:call-template>

		<div id="details_container" class="section_container details_container_class" style="{$displayStyle}" inAllAction="true">
			<table>

				<!--BEGIN SOURCE FILE-->
				<xsl:apply-templates select="./optimreport:file">
					<xsl:with-param name="tableName">Source File</xsl:with-param>
				</xsl:apply-templates>
				<!--END SOURCE FILE-->

				<!--BEGIN CONTROL FILE-->
				<xsl:apply-templates select="./optimreport:controlFile"/>
				<!--END CONTROL FILE-->
				
			</table>
			<xsl:call-template name="deleteEntities" />
		</div>

		<xsl:if test="optimreport:impactAnalysisResults/optimreport:impactAnalysis">
			<xsl:apply-templates select="optimreport:impactAnalysisResults" />
		</xsl:if>

		<xsl:if test="optimreport:statistics/optimreport:statistic">
			<xsl:apply-templates select="optimreport:statistics" />
		</xsl:if>

		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>
	<!--  END DeleteReport section -->
	
	<!-- BEGIN entities section -->
	<xsl:template name="deleteEntities">
			<table class="entity_details">
				<tr>
					<th style="min-width: 125px;">
						<center><xsl:text>Name</xsl:text></center>
					</th>
					<td >
						<center><b><xsl:text>Deleted</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Skipped</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Failed</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Type</xsl:text></b></center>
					</td>
				</tr>
				<xsl:for-each select="optimreport:entities/optimreport:entity">
					<tr>
						<th>
							<xsl:text>&#160;&#160;&#160;</xsl:text>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@name" />
							</xsl:call-template>
						</th>
						<td>
							<xsl:choose>
								<xsl:when test='not(number(@recordCount) = number(@recordCount))'>
									<xsl:call-template name='stringCheck'>
										<xsl:with-param name='value' select='@recordCount'/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="numberFormat">
										<xsl:with-param name="number" select="@recordCount"/>
										<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:choose>
								<xsl:when test='not(number(@skipped) = number(@skipped))'>
									<xsl:call-template name='stringCheck'>
										<xsl:with-param name='value' select='@skipped'/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="numberFormat">
										<xsl:with-param name="number" select="@skipped"/>
										<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:choose>
								<xsl:when test='not(number(@failed) = number(@failed))'>
									<xsl:call-template name='stringCheck'>
										<xsl:with-param name='value' select='@failed'/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="numberFormat">
										<xsl:with-param name="number" select="@failed"/>
										<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@type"/>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:for-each>
			</table>
	</xsl:template>
	<!-- END entities section -->
	

</xsl:stylesheet>

